# Redis OM for Python

Welcome! This is the documentation for redis-om-python.

**NOTE**: The documentation is a bit sparse at the moment but will continue to grow!

## Getting Started

Read the Getting Started tutorial at [getting_started.md](getting_started.md).

## Connecting to Redis

Read about connecting to Redis at [connections.md](connections.md).

## Models and Fields

Learn all about how to create model instances and define fields in [models.md](models.md).

## Validating Data

Read about how to use Redis OM models to validate data at [validation.md](validation.md)

## Redis Modules

Read how to get the RediSearch and RedisJSON modules at [redis_modules.md](redis_modules.md).

## FastAPI Integration

Redis OM is designed to integrate with the FastAPI web framework. See how this works at [fastapi_integration.md](fastapi_integration.md).

## Error Messages

Get help with (some of) the error messages you might see from Redis OM: [errors.md](errors.md)
